package com.playlet.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.playlet.system.domain.PlayletItem;

import java.util.List;

/**
 * @Date: 2024-03-14-22:51
 * @Author: 但星霖
 * @Version: v1.0
 * @Description: 短剧基础Mapper接口
 */
public interface PlayletItemMapper extends BaseMapper<PlayletItem> {
    /**
     * 查询短剧基础
     *
     * @param id 短剧基础主键
     * @return 短剧基础
     */
    public PlayletItem selectPlayletItemById(Long id);

    /**
     * 查询短剧基础列表
     *
     * @param playletItem 短剧基础
     * @return 短剧基础集合
     */
    public List<PlayletItem> selectPlayletItemList(PlayletItem playletItem);

    /**
     * 新增短剧基础
     *
     * @param playletItem 短剧基础
     * @return 结果
     */
    public int insertPlayletItem(PlayletItem playletItem);

    /**
     * 修改短剧基础
     *
     * @param playletItem 短剧基础
     * @return 结果
     */
    public int updatePlayletItem(PlayletItem playletItem);

    /**
     * 删除短剧基础
     *
     * @param id 短剧基础主键
     * @return 结果
     */
    public int deletePlayletItemById(Long id);

    /**
     * 批量删除短剧基础
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletItemByIds(String[] ids);
}
